import { useCallback } from "react";
import { Background, Controls, ReactFlow, Node, useNodesState, useEdgesState, addEdge, Connection } from "@xyflow/react";
import * as node from "./node/";

import "@xyflow/react/dist/style.css";

import { History, Impl as HistoryImpl } from "./context/History";

const nodeTypes = {
  fetch_ToshoListed: node.fetch.ToshoListed,
};
const initialNodes: Node[] = [
  {id: "n1", type: "fetch_ToshoListed", position: {x:0, y:0}, data: {prime: true, standard: true, growth: true}},
  {id: "n2", position: {x:0, y:100}, data: {label: "hi"}},
  {id: "n3", position: {x:0, y:200}, data: {label: "hello"}},
];

export default function Screening() {
  const [nodes, setNodes, onNodesChange] = useNodesState(initialNodes);
  const [edges, setEdges, onEdgesChange] = useEdgesState([]);

  const onConnect = useCallback(
    (connection: Connection) => setEdges((eds) => addEdge(connection, eds)),
    []
  );

  return (
    <History.Provider value={new HistoryImpl(setNodes)}>
      <div style={{ position: "absolute", left: 0, right: 0, top: 0, bottom: 0 }}>
        <ReactFlow
          nodeTypes={nodeTypes}
          nodes={nodes}
          edges={edges}
          onNodesChange={onNodesChange}
          onEdgesChange={onEdgesChange}
          onConnect={onConnect}
          fitView
        >
          <Controls />
          <Background />
        </ReactFlow>
      </div>
    </History.Provider>
  );
}
