import { useContext } from "react";
import { useTranslation } from "react-i18next";
import { Handle, Node, NodeProps, Position } from "@xyflow/react";
import Base from "./Base";

import History from "../context/History";

export type ToshoListed = Node<{
  prime: boolean,
  standard: boolean,
  growth: boolean,
}, "ToshoListed">;
export function ToshoListed({id, data}: NodeProps<ToshoListed>) {
  const {t} = useTranslation();

  const history = useContext(History);
  if (history === undefined) {
    throw new Error("no History context");
  }

  return (
    <Base title={t("pages.screening.nodes.fetch_ToshoListed.title")}>
      <div>
        <div><label>
          <input
            type="checkbox"
            name="prime"
            checked={data.prime}
            onChange={(e)=>history.push(id, {...data, prime: e.target.checked})}
          />
          {t("terms.toshoPrime")}
        </label></div>
        <div><label>
          <input
            type="checkbox"
            name="standard"
            checked={data.standard}
            onChange={(e)=>history.push(id, {...data, standard: e.target.checked})}
          />
          {t("terms.toshoStandard")}
        </label></div>
        <div><label>
          <input
            type="checkbox"
            name="growth"
            checked={data.growth}
            onChange={(e)=>history.push(id, {...data, growth: e.target.checked})}
          />
          {t("terms.toshoGrowth")}
        </label></div>
      </div>
      <Handle type="source" position={Position.Right}/>
    </Base>
  );
}

